@@ -22,8 +22,9 @@ def nlp_dict():
     nlp_sv = spacy.blank("sv")  # spacy has no Swedish pipelines
     nlp_sv.add_pipe("sentencizer")
     nlp_nb = spacy.load("nb_core_news_sm")
+    nlp_de = spacy.load("de_core_news_sm")
 
-    return {"da": nlp_da, "en": nlp_en, "no": nlp_nb, "sv": nlp_sv}
+    return {"da": nlp_da, "en": nlp_en, "no": nlp_nb, "sv": nlp_sv, "de": nlp_de}
 
 
 @pytest.mark.parametrize(
@@ -166,9 +167,14 @@ def test_token_polarity(
 def test_span_doc_polarity(example: str, expected: str, lang: str, nlp_dict):
     nlp = nlp_dict[lang]
     lexicon = asent.lexicons.get("lexicon_" + lang + "_v1")
-    negations = asent.lexicons.get("negations_" + lang + "_v1")
-    intensifiers = asent.lexicons.get("intensifiers_" + lang + "_v1")
-    if lang != "sv":
+
+    if lang in {"da", "sv"}:
+        negations = asent.lexicons.get("negations_" + lang + "_v1")
+        intensifiers = asent.lexicons.get("intensifiers_" + lang + "_v1")
+    else:
+        negations = set()
+        intensifiers = {}
+    if lang in {"da"}:
         cconj = asent.lexicons.get("contrastive_conj_" + lang + "_v1")
     else:
         cconj = set()
